@@ -1056,7 +1056,13 @@ class PonLink(BaseWrapperClass):
     @rx_power.setter
     def rx_power(self, value):
         if value is not None:
-            self.pb.rx_power = value
+            if value >= -50 and value <= 50:
+                self.pb.rx_power = value
+            elif self.errctx:
+                self.errctx.add(network_poller_pb2.PollError.ERROR_BAD_DATA_RANGE,
+                                'Invalid value for NetworkElement.PonLink.rx_power',
+                                value=value,
+                                metric_name='NetworkElement.PonLink.rx_power')
         else:
             self.pb.ClearField('rx_power')
 
@@ -1067,7 +1073,13 @@ class PonLink(BaseWrapperClass):
     @tx_power.setter
     def tx_power(self, value):
         if value is not None:
-            self.pb.tx_power = value
+            if value >= -50 and value <= 50:
+                self.pb.tx_power = value
+            elif self.errctx:
+                self.errctx.add(network_poller_pb2.PollError.ERROR_BAD_DATA_RANGE,
+                                'Invalid value for NetworkElement.PonLink.tx_power',
+                                value=value,
+                                metric_name='NetworkElement.PonLink.tx_power')
         else:
             self.pb.ClearField('tx_power')
 
